@@ -503,36 +503,25 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
         or np.any(xyCoord < 0)
         or np.any(xyCoord > np.array(self.imgItem.image.shape[:2][::-1]) - 1)):
       return
-    cursorClr = self.imgItem.image[xyCoord[1], xyCoord[0],...].astype(int)
-    if cursorClr.ndim == 0:
-      cursorClr = np.array([cursorClr])
-    self.updateCursorInfo(xyCoord, cursorClr)
+    imgValue = self.imgItem.image[xyCoord[1], xyCoord[0],...].astype(int)
+    self.updateCursorInfo(xyCoord, imgValue)
     self.sigMouseMoved.emit(xyCoord)
 
-  def updateCursorInfo(self, xyPos: np.ndarray, pxColor: np.ndarray):
-    if pxColor is None: return
+  def updateCursorInfo(self, xyPos: np.ndarray, pxValue: np.ndarray):
+    if pxValue is None: return
     if self.mouseCoordsLbl is not None:
       self.mouseCoordsLbl.setText(f'Mouse (x,y): {xyPos[0]}, {xyPos[1]}')
 
     if self.pxColorLbl is None:
       return
-    self.pxColorLbl.setText(f'Pixel Color: {pxColor}')
-    if pxColor.dtype == float:
-      # Turn to uint
-      pxColor = (pxColor*255).astype('uint8')
-    # Regardless of the number of image channels, display as RGBA color
-    if pxColor.size == 1:
-      # noinspection PyTypeChecker
-      pxColor = np.array(pxColor.tolist()*3 + [255])
-    elif pxColor.size == 3:
-      pxColor = np.concatenate([pxColor, [255]])
-    # Else: assume already RGBA
-    # Determine text color based on background color
-    if np.mean(pxColor) > 127:
-      fontColor = 'black'
-    else:
-      fontColor = 'white'
-    self.pxColorLbl.setStyleSheet(f'background:rgba{tuple(pxColor)}; color:{fontColor}')
+    self.pxColorLbl.setText(f'Pixel Color: {pxValue}')
+    if self.imgItem.qimage is None:
+      return
+    # Cheap way of splitting the int32 return value into uint8 RGBA
+    imColor = np.array([self.imgItem.qimage.pixel(*xyPos)], 'int32').view('uint8')
+    grayClr = np.mean(imColor[:3])
+    fontColor = 'black' if grayClr > 127 else 'white'
+    self.pxColorLbl.setStyleSheet(f'background:rgba{tuple(imColor)}; color:{fontColor}')
 
   def setImage(self, imgSrc: t.Union[FilePath, np.ndarray]=None):
     """
@@ -553,7 +542,7 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
     else:
       self.imgItem.setImage(imgSrc)
 
-  def widgetContainer(self, asMainWin=False, showTools=True, **kwargs):
+  def widgetContainer(self, asMainWin=True, showTools=True, **kwargs):
     """
     Though this is a PlotWidget class, it has a lot of widget children (toolsEditor group, buttons) that are
     not visible when spawning the widget. This is a convenience method that creates a new, outer widget
@@ -578,6 +567,11 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
       wid = EasyWidget.buildWidget(self._widgetContainerChildren(), **kwargs)
     return wid
 
+  def show_exec(self):
+    win = self.widgetContainer(True)
+    QtCore.QTimer.singleShot(0, win.showMaximized)
+    QtCore.QCoreApplication.instance().exec_()
+
 
   def _widgetContainerChildren(self):
     """
@@ -820,6 +814,9 @@ class MaskCompositor(ImageViewer):
       pType: filepicker
     :param toClipboard: Whether to copy to clipboard
     :param cropToViewbox: Whether to only save the visible portion of the image
+    :param floatLegend: Whether to ancor the legend in the top-left corner (if *False*) or
+      put it exactly where it is positioned currently (if *True*). In the latter case, it may not appear if out of view
+      and `cropToViewbox` is *True*.
     """
     if self.imgItem.isVisible():
       saveImg = self.imgItem.getPixmap()
@@ -880,11 +877,6 @@ class MaskCompositor(ImageViewer):
       self.legend.setParentItem(self.plotItem)
       self.legend.autoAnchor(oldPos, relative=False)
 
-  def show_exec(self):
-    super().show()
-    pg.mkQApp().exec_()
-
-
 class PandasTableModel(QtCore.QAbstractTableModel):
   """
   Class to populate a table view with a pandas dataframe
